==> messagelib-17.04.1.tar.xz: messagelib-17.04.1/mimetreeparser/autotests/testcsshelper.h <==
/*  -*- c++ -*-
    testcsshelper.h

    This file is part of KMail, the KDE mail client.
    Copyright (c) 2013 Sandro Knauß <bugs@sandroknauss.de>

    KMail is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License, version 2, as
    published by the Free Software Foundation.

    KMail is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __MIMETREEPARSER_TESTCSSHELPER_H__
#define __MIMETREEPARSER_TESTCSSHELPER_H__

#include "viewer/csshelperbase.h"

namespace MimeTreeParser
{

class TestCSSHelper : public CSSHelperBase
{
public:
    explicit TestCSSHelper(const QPaintDevice *pd);
    virtual ~TestCSSHelper();
    QString htmlHead(bool fixed) const Q_DECL_OVERRIDE;
};

}

#endif // __MIMETREEPARSER_TESTCSSHELPER_H__

==> messagelib-17.08.3.tar.xz: messagelib-17.08.3/mimetreeparser/autotests/testcsshelper.h <==
/*  -*- c++ -*-
    testcsshelper.h

    This file is part of KMail, the KDE mail client.
    Copyright (c) 2013 Sandro Knauß <bugs@sandroknauss.de>

    KMail is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License, version 2, as
    published by the Free Software Foundation.

    KMail is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __MIMETREEPARSER_TESTCSSHELPER_H__
#define __MIMETREEPARSER_TESTCSSHELPER_H__

#include "viewer/csshelperbase.h"

namespace MimeTreeParser
{

class TestCSSHelper : public CSSHelperBase
{
public:
    explicit TestCSSHelper(const QPaintDevice *pd);
    virtual ~TestCSSHelper();
    QString htmlHead(bool fixed) const override;
};

}

#endif // __MIMETREEPARSER_TESTCSSHELPER_H__
